@@ -2,20 +2,22 @@
 library("msaenet")
 
 ## ------------------------------------------------------------------------
-dat = msaenet.sim.gaussian(
+dat <- msaenet.sim.gaussian(
   n = 150, p = 500, rho = 0.7,
   coef = rep(1, 5), snr = 3, p.train = 0.7,
-  seed = 1001)
+  seed = 1001
+)
 
 ## ------------------------------------------------------------------------
-msaenet.fit = msaenet(
+msaenet.fit <- msaenet(
   dat$x.tr, dat$y.tr,
   alphas = seq(0.1, 0.9, 0.1),
   nsteps = 10L, tune.nsteps = "ebic",
-  seed   = 1005)
+  seed = 1005
+)
 
 ## ---- eval=FALSE---------------------------------------------------------
-#  library(doParallel)
+#  library("doParallel")
 #  registerDoParallel(detectCores())
 
 ## ------------------------------------------------------------------------
@@ -26,7 +28,7 @@ msaenet.fp(msaenet.fit, 1:5)
 msaenet.tp(msaenet.fit, 1:5)
 
 ## ------------------------------------------------------------------------
-msaenet.pred = predict(msaenet.fit, dat$x.te)
+msaenet.pred <- predict(msaenet.fit, dat$x.te)
 msaenet.rmse(dat$y.te, msaenet.pred)
 msaenet.mae(dat$y.te, msaenet.pred)
 
